@@ -50,6 +50,7 @@
 #include <tdemessagebox.h>
 #include <kservice.h>
 #include <kstandarddirs.h>
+#include <kprocess.h>
 #include <krun.h>
 
 #include <tqclipboard.h>
@@ -922,11 +923,14 @@ void Dolphin::goHome()
 
 void Dolphin::openTerminal()
 {
-    TQString command("konsole --workdir \"");
-    command.append(m_activeView->url().path());
-    command.append('\"');
+    TDEConfig * config = kapp->config();
+    config->setGroup("General");
+    TQString term = config->readPathEntry("TerminalApplication", "konsole");
 
-    KRun::runCommand(command, "Konsole", "konsole");
+    TDEProcess proc;
+    proc << term;
+    proc.setWorkingDirectory(m_activeView->url().path());
+    proc.start(TDEProcess::DontCare);
 }
 
 void Dolphin::findFile()
