@@ -22,9 +22,9 @@
 
 #include <tqlayout.h>
 #include <kurl.h>
-#include <klocale.h>
-#include <kio/netaccess.h>
-#include <kio/renamedlg.h>
+#include <tdelocale.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/renamedlg.h>
 #include <assert.h>
 
 #include "urlnavigator.h"
@@ -102,7 +102,7 @@ DolphinView::DolphinView(TQWidget *parent,
     connect(m_dirLister, TQT_SIGNAL(newItems(const KFileItemList&)),
            this, TQT_SLOT(slotAddItems(const KFileItemList&)));
 
-    m_iconSize = KIcon::SizeMedium;
+    m_iconSize = TDEIcon::SizeMedium;
 
     m_topLayout->addWidget(m_urlNavigator);
     createView();
@@ -244,7 +244,7 @@ void DolphinView::renameSelectedItems()
                     KURL dest(source.upURL());
                     dest.addPath(name);
 
-                    const bool destExists = KIO::NetAccess::exists(dest, false, view);
+                    const bool destExists = TDEIO::NetAccess::exists(dest, false, view);
                     if (destExists) {
                         delete progressIndicator;
                         progressIndicator = 0;
@@ -252,7 +252,7 @@ void DolphinView::renameSelectedItems()
                                                       DolphinStatusBar::Error);
                         break;
                     }
-                    else if (KIO::NetAccess::file_move(source, dest)) {
+                    else if (TDEIO::NetAccess::file_move(source, dest)) {
                         // TODO: From the users point of view he executed one 'rename n files' operation,
                         // but internally we store it as n 'rename 1 file' operations for the undo mechanism.
                         DolphinCommand command(DolphinCommand::Rename, source, dest);
@@ -538,27 +538,27 @@ void DolphinView::rename(const KURL& source, const TQString& newName)
     KURL dest(source.upURL());
     dest.addPath(newName);
 
-    const bool destExists = KIO::NetAccess::exists(dest,
+    const bool destExists = TDEIO::NetAccess::exists(dest,
                                                    false,
                                                    Dolphin::mainWin().activeView());
     if (destExists) {
         // the destination already exists, hence ask the user
         // how to proceed...
-        KIO::RenameDlg renameDialog(this,
+        TDEIO::RenameDlg renameDialog(this,
                                     i18n("File Already Exists"),
                                     source.path(),
                                     dest.path(),
-                                    KIO::M_OVERWRITE);
+                                    TDEIO::M_OVERWRITE);
         switch (renameDialog.exec()) {
-            case KIO::R_OVERWRITE:
+            case TDEIO::R_OVERWRITE:
                 // the destination should be overwritten
-                ok = KIO::NetAccess::file_move(source, dest, -1, true);
+                ok = TDEIO::NetAccess::file_move(source, dest, -1, true);
                 break;
 
-            case KIO::R_RENAME: {
+            case TDEIO::R_RENAME: {
                 // a new name for the destination has been used
                 KURL newDest(renameDialog.newDestURL());
-                ok = KIO::NetAccess::file_move(source, newDest);
+                ok = TDEIO::NetAccess::file_move(source, newDest);
                 break;
             }
 
@@ -571,7 +571,7 @@ void DolphinView::rename(const KURL& source, const TQString& newName)
     else {
         // no destination exists, hence just move the file to
         // do the renaming
-        ok = KIO::NetAccess::file_move(source, dest);
+        ok = TDEIO::NetAccess::file_move(source, dest);
     }
 
     if (ok) {
@@ -645,7 +645,7 @@ void DolphinView::slotURLChanged(const KURL& url)
 
 void DolphinView::triggerIconsViewItem(TQIconViewItem* item)
 {
-    const ButtonState keyboardState = KApplication::keyboardMouseState();
+    const ButtonState keyboardState = TDEApplication::keyboardMouseState();
     const bool isSelectionActive = ((keyboardState & ShiftButton) > 0) ||
                                    ((keyboardState & ControlButton) > 0);
     if ((item != 0) && !isSelectionActive) {
@@ -971,7 +971,7 @@ TQString DolphinView::selectionStatusBarText() const
 
     int fileCount = 0;
     int folderCount = 0;
-    KIO::filesize_t byteSize = 0;
+    TDEIO::filesize_t byteSize = 0;
     for (KFileItemListIterator it(*list); it.current() != 0; ++it) {
         KFileItem* item = it.current();
         if (item->isDir()) {
@@ -992,7 +992,7 @@ TQString DolphinView::selectionStatusBarText() const
     }
 
     if (fileCount > 0) {
-        const TQString sizeText(KIO::convertSize(byteSize));
+        const TQString sizeText(TDEIO::convertSize(byteSize));
         text += i18n("1 File selected (%1)", "%n Files selected (%1)", fileCount).arg(sizeText);
     }
 
